---
title: 포트원 제공 서비스
category: 포트원 서비스 (포트원 제공 서비스) > 포트원 서비스 > 포트원 서비스
seo:
  title: 포트원 제공 서비스
  description: 포트원에서 제공하는 서비스를 소개합니다.
  keywords:
    - 결제사정산
    - 파트너정산
    - 파트너정산자동화
    - 애널리틱스
    - 결제데이터분석
    - 해외결제
    - 크로스보더
tags:
  - 포트원
searchTags:
  - 포트원부가서비스
  - 포트원
  - 포트원서비스
---

## **통합 결제 솔루션**



- 통합 결제 API 포트원 API를 통한 연동 개발 리소스 절감
- 결제 대행사 및 결제수단 연동 국내외 30개 PG사를 통한 최적의 결제수단 선택 가능
- 데이터 통합 관리 관리자콘솔을 통한 PG사 결제 데이터 확인 / 취소 / 환불 / 현금영수증 관리

<Callout title="통합 결제 솔루션 보러가기↗" />

## **크로스보더**



- 국가별 결제수단 최적화 신용카드, 계좌이체, E-Wallet 등 국가별 고객이 선호하는 결제 수단 제공
- 글로벌 호스팅 플러그인 지원 쇼피파이, 우커머스, 마젠토, 오픈카트 지원
- 모바일 / 간편 결제수단 지원 App to App, QR 결제, 링크페이 등 다양한 결제수단 지원
- 결제실패방지(Failover)기능 지원 현지 결제 경험 강화를 위한 결제트래픽 분산

<Callout title="크로스보더 서비스 보러가기↗" />

## **파트너 정산 자동화**



- 계약 관리 셀러별 맞춤 수수료 적용, 쿠폰/프로모션 등 할인 분담률 설정
- 파트너 등록/관리 파트너별 계약 관리, 정산 계좌정보 등록 및 검증
- 정산 내역 관리 수동이체 및 별도 정산건 관리, 취환불 처리, 품목별 다건 정산 지원
- 이체 관리 대량 이체를 위한 엑셀 파일 다운로드, 이체 내역 관리, 외환 송금 지원
- API 지원을 통한 데이터 편의성

<Callout title="파트너 정산 자동화 서비스 보러가기↗" />

## PG 거래 대사



- PG 거래 데이터 통합 조회 및 대사 기능 제공
- PG 정산 데이터 통합 조회를 통한 정산 예정/완료 금액, PG 수수료 금액 확인
- 조회 기간, 결제 수단, PG, 상점아이디 조건에 따른 필터 기능 제공
- 부가세 참고 자료 다운로드 기능 제공

<Callout title="PG 거래 대사 서비스 보러가기↗" />

## **결제 데이터 분석**



- 결제 대시보드 무료 구축 하나의 대시보드로 일별, 월별, 분기별 결제 데이터 확인
- 고객 선호 결제 수단, 결제 대행사 파악 결제 수단 현황, 트렌드 분석을 통해 결제 대행사별 성과 파악
- 결제 전환율 개선 결제 상태 현황, 실패 사유, 분석 기능 제공
- 실시간 모니터링 장애 발생 시, 발생 원인을 파악하여 빠른 실시간 장애 대응 가능

<Callout title="결제 데이터 분석 서비스 보러가기↗" />

---

<Callout title="포트원 도입문의 신청하러 가기" />
